# to7m_context

A simple convenience package which adds {package_root}/src as an import path, thereby allowing contained packages to be imported. This package must be imported from a file within {package_root} for it to work.
